@@ -20,32 +20,14 @@ iclust = {factors <- as.matrix(fa.results$loadings)
              if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
 fa = {factors <- as.matrix(fa.results$loadings)
              if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
+principal = {factors <- as.matrix(fa.results$loadings)
+             if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
 extension = {factors <- as.matrix(fa.results$loadings)
              if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
 extend = {factors <- as.matrix(fa.results$loadings)
              if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}},
 other = {factors <- fa.results})
 
-
-if(FALSE) {#delete this once it works
-if(!is.null(class(fa.results)) && (length(class(fa.results)) > 1)) {  #is the input a list structure from fa or omega or iclust
-   if(class(fa.results)[2] =="omega") {
-        omega <- TRUE
-        factors <- as.matrix(fa.results$schmid$oblique)
-        sl <- fa.results$schmid$sl
-         } else {  #the normal factor case is fa or iclust output
-
-      Phi <- NULL  #the default case
-      if((!is.matrix(fa.results)) && (!is.data.frame(fa.results)))  { #make sure that we weren't just given a matrix to draw
-             factors <- as.matrix(fa.results$loadings)
-             if(!is.null(fa.results$Phi))  {Phi <- fa.results$Phi}
-           } 
-           }
-           } else {
-                   factors <- fa.results}
-          
- } #end of code to be deleted eventually
-
 nitems <- dim(factors)[1]
 nfactors <- dim(factors)[2]
 total.ord <- rep(NA,nitems)
