@@ -35,4 +35,34 @@ if(!freq) {lines(d,lty=dlty[1],col=dcol[1],...)
 curve(dnorm(x,m1,s1),add=TRUE,lty=dlty[2],col=dcol[2],...)} else {
 lines(d$x,lty=dlty[1],col=dcol[1],...)}
       
+}
+
+
+
+"histBy" <- function(x,var,group,density=TRUE,alpha=.5,breaks=21,col,xlab,main="Histograms by group",...) {
+if(missing(xlab)) xlab = var
+if(missing(group)) {
+   if(missing(col)) col12 <- col2rgb("blue",TRUE)/255
+    col <- rgb(col12[1],col12[2],col12[3],alpha)
+   hist(x[,var],xlab=xlab,main=main,breaks=breaks,freq=FALSE,col=col,...)
+      d <- density(x[,var],na.rm=TRUE)
+      if(density) lines(d)
+ } else { #the normal case 
+gr <- x[group]                
+grp<- table(gr)
+
+if(missing(col)) col <- rainbow(length(grp))
+col12 <- col2rgb(col,TRUE)/255
+col <- rgb(col12[1,],col12[2,],col12[3,],alpha)
+
+xlim=range(x[var],na.rm=TRUE)
+grp <- names(grp)
+d <- density(x[(gr==grp[1]),var],na.rm=TRUE)
+hist(x[(gr==grp[1]),var],xlim=xlim,col=col[1],breaks=breaks,freq=FALSE,xlab=xlab,main=main,...) 
+if(density) lines(d)
+for(i in (2:length(grp))) {
+ hist(x[(gr==grp[i]),var],col=col[i],freq=FALSE,breaks=breaks,add=TRUE,...)
+d <- density(x[(gr==grp[i]),var],na.rm=TRUE)
+if(density) lines(d)
+}}
 }
\ No newline at end of file
