@@ -52,7 +52,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
       if(rotate != "none") {if (nfactors > 1) {
   
    	if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" |rotate =="bifactor"  |rotate =="varimin" |rotate =="targetT" |rotate =="equamax") { 
-   	if (!require(GPArotation)) {stop("I am sorry, to do these rotations requires the GPArotation package to be installed")}
+   	if (!requireNamespace('GPArotation')) {stop("I am sorry, to do these rotations requires the GPArotation package to be installed")}
    	       #varimax is from the stats package, Varimax is from GPArotations
    	       colnames(loadings) <- paste("RC",1:nfactors,sep='')  #to remind us that we are rotating the components 
    			rotated <- do.call(rotate,list(loadings,...))
@@ -69,7 +69,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
      			                Phi <- pro$Phi} else {
      			                     
      			if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax" | rotate =="geominQ"  | rotate =="bentlerQ" |rotate == "biquartimin" |rotate == "targetQ" |rotate == "TargetQ" ) {
-     				if (!require(GPArotation)) {warning("I am sorry, to do these rotations requires the GPArotation package to be installed")
+     				if (!requireNamespace('GPArotation')) {warning("I am sorry, to do these rotations requires the GPArotation package to be installed")
      				Phi <- NULL} else {
      				 colnames(loadings) <- paste("TC",1:nfactors,sep='')  #to remind us that we are Transforming the components 
      				  ob  <- try(do.call(rotate,list(loadings,...) ))
@@ -78,7 +78,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
      				                 
      				loadings <- ob$loadings
      				 Phi <- ob$Phi}
-     		                             }
+     		                              } else {message("Specified rotation not found, rotate='none' used")} #added 30/11/14 
      	               }}}
     
      }}
