@@ -1,5 +1,11 @@
 "set.cor" <-
-function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",square=FALSE)  {
+function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="Regression Models")  {
+setCor(y=y,x=x,data=data,z=z,n.obs=n.obs,use=use,std=std,square=square,main=main)}
+
+
+"setCor" <-
+function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",std=TRUE,square=FALSE,main="Regression Models")  {
+
  #a function to extract subsets of variables (a and b) from a correlation matrix m or data set m
   #and find the multiple correlation beta weights + R2 of the a set predicting the b set
   #seriously rewritten, March 24, 2009 to make much simpler
@@ -7,16 +13,18 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",square=FALSE)  {
   #major addition in April, 2011 to allow for set correlation
   #added calculation of residual matrix December 30, 2011
   #added option to allow square data matrices
+  #modified December, 2014  to allow for covariances as well as to fix a bug with single x variable
+  
    cl <- match.call()
-   cor <- TRUE  #fix this to allow this to a parameter
+
   if(!is.matrix(data)) data <- as.matrix(data)
   if((dim(data)[1]!=dim(data)[2]) | square)  {n.obs=dim(data)[1]   #this does not take into account missing data
                     C <- cov(data,use=use)
-                    if(cor) {m <- cov2cor(C)} else {m <- C}
+                    if(std) {m <- cov2cor(C)} else {m <- C}
                     raw <- TRUE}  else {
                     raw <- FALSE
-                    C <-data
-                    if(cor) {m <- cov2cor(C)} else {m <- C}}
+                    C <- data
+                    if(std) {m <- cov2cor(C)} else {m <- C}}
    #convert names to locations                 
    if(is.character(x)) x <- which(colnames(data) == x)
    if(is.character(y)) y <- which(colnames(data) == y) 
@@ -34,9 +42,9 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",square=FALSE)  {
      	xy.matrix <- m[x,y,drop=FALSE]
      	xyc.matrix <- C[x,y,drop=FALSE]
      	y.matrix <- m[y,y,drop=FALSE]
-     	if(!is.null(z)){numz <- length(z)
+     	if(!is.null(z)){numz <- length(z)      #partial out the z variables
      	                zm <- m[z,z,drop=FALSE]
-     	                 za <- m[x,z,drop=FALSE]
+     	                za <- m[x,z,drop=FALSE]
      	                 zb <- m[y,z,drop=FALSE]
      	                 x.matrix <- x.matrix - za %*% solve(zm) %*% t(za)
      	                 y.matrix <- y.matrix - zb %*% solve(zm) %*% t(zb)
@@ -44,22 +52,29 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",square=FALSE)  {
      	                m.matrix <- cbind(rbind(y.matrix,xy.matrix),rbind(t(xy.matrix),x.matrix))
      	                
      	                 }
-     	if(numx == 1 ) {beta <- matrix(xy.matrix,nrow=1)
+     	if(numx == 1 ) {beta <- matrix(xy.matrix,nrow=1)/x.matrix[1,1]
      	                } else   #this is the case of a single x 
       				 { beta <- solve(x.matrix,xy.matrix)       #solve the equation bY~aX
        					 beta <- as.matrix(beta) 
        					 }
-       				 
+
+
        	yhat <- t(xy.matrix) %*% solve(x.matrix) %*% (xy.matrix)
        	resid <- y.matrix - yhat
-     	if (numy >1 ) { if(is.null(rownames(beta))) {rownames(beta) <- colnames(m)[x]}
+     	if (numy > 1 ) { if(is.null(rownames(beta))) {rownames(beta) <- colnames(m)[x]}
      	                if(is.null(colnames(beta))) {colnames(beta) <- colnames(m)[y]}
      	 
-     	 R2 <- colSums(beta * xy.matrix) } else { colnames(beta) <- colnames(data)[y]
-     		 R2 <- sum(beta * xy.matrix)
-     	 	 rownames(beta) <- colnames(data)[x]
-     		 names(R2) <- colnames(data)[y]}
-     		 
+     	 R2 <- colSums(beta * xy.matrix)/diag(y.matrix) } else {  
+     	 colnames(beta) <- colnames(data)[y] 
+     		
+     		 R2 <- sum(beta * xy.matrix)/y.matrix
+     		 R2 <- matrix(R2)
+     		      	 	 rownames(beta) <- colnames(data)[x]
+     		 rownames(R2) <- colnames(R2) <- colnames(data)[y]
+     		 }
+     	
+     	
+     	
      	#now find the unit weighted correlations  
      	#reverse items in X and Y so that they are all positive signed
      	 px <- principal(x.matrix)
@@ -89,17 +104,18 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",square=FALSE)  {
      	       
      	if(!is.null(n.obs)) {k<- length(x)
      	                     
+     	                    # uniq <- (1-smc(x.matrix,covar=!std))
      	                     uniq <- (1-smc(x.matrix))
      	                     se.beta <- list() 
      	                     for (i in 1:length(y)) {
      	                     df <- n.obs-k-1
-     	                     se.beta[[i]] <- (sqrt((1-R2[i])/(df))*sqrt(1/uniq))}
+     	                     se.beta[[i]] <- (sqrt((1-R2[i])/(df))*sqrt(1/uniq))}    #why is uniq not indexed if R2 is?
      	                     se <- matrix(unlist(se.beta),ncol=length(y))
      	                     colnames(se) <- colnames(beta)
      	                     rownames(se) <- rownames(beta)
-     	                     tvalue <- beta/se
-     	                     se <- t(t(se) * sqrt(diag(C)[y]))/sqrt(diag(xc.matrix))
      	                     
+     	                     se <- t(t(se) * sqrt(diag(C)[y]))/sqrt(diag(xc.matrix))
+     	                     tvalue <- beta/se
      	                prob <- 2*(1- pt(abs(tvalue),df))
      	                     SE2 <- 4*R2*(1-R2)^2*(df^2)/((n.obs^2-1)*(n.obs+3))
      	                     SE =sqrt(SE2)
@@ -130,17 +146,62 @@ function(y,x,data,z=NULL,n.obs=NULL,use="pairwise",square=FALSE)  {
      	                   
      	                              }
      	
-     	if(numx == 1) {beta <-  beta * sqrt(diag(C)[y])
-     	   } else {beta <-  t(t(beta) * sqrt(diag(C)[y]))/sqrt(diag(xc.matrix))} #this puts the betas into the raw units
+     #	if(numx == 1) {beta <-  beta * sqrt(diag(C)[y])
+     #	   } else {beta <-  t(t(beta) * sqrt(diag(C)[y]))/sqrt(diag(xc.matrix))} #this puts the betas into the raw units
         
-     	if(is.null(n.obs)) {set.cor <- list(beta=beta,R=sqrt(R2),R2=R2,Rset=Rset,T=T,cancor = cc, cancor2=cc2,raw=raw,residual=resid,ruw=ruw,Ruw=Ruw,Call = cl)} else {
-     	              set.cor <- list(beta=beta,se=se,t=tvalue,Probability = prob,R=sqrt(R2),R2=R2,shrunkenR2 = shrunkenR2,seR2 = SE,F=F,probF=pF,df=c(k,df),Rset=Rset,Rset.shrunk=R2set.shrunk,Rset.F=Rset.F,Rsetu=u,Rsetv=df.v,T=T,cancor=cc,cancor2 = cc2,Chisq = Chisq,raw=raw,residual=resid,ruw=ruw,Ruw=Ruw,Call = cl)}
-     	class(set.cor) <- c("psych","set.cor")
+     	if(is.null(n.obs)) {set.cor <- list(beta=beta,R=sqrt(R2),R2=R2,Rset=Rset,T=T,cancor = cc, cancor2=cc2,raw=raw,residual=resid,ruw=ruw,Ruw=Ruw,x.matrix=x.matrix,y.matrix=y.matrix,Call = cl)} else {
+     	              set.cor <- list(beta=beta,se=se,t=tvalue,Probability = prob,R=sqrt(R2),R2=R2,shrunkenR2 = shrunkenR2,seR2 = SE,F=F,probF=pF,df=c(k,df),Rset=Rset,Rset.shrunk=R2set.shrunk,Rset.F=Rset.F,Rsetu=u,Rsetv=df.v,T=T,cancor=cc,cancor2 = cc2,Chisq = Chisq,raw=raw,residual=resid,ruw=ruw,Ruw=Ruw,x.matrix=x.matrix,y.matrix=y.matrix,Call = cl)}
+     	class(set.cor) <- c("psych","setCor")
+     	setCor.diagram(set.cor,main=main)
      	return(set.cor)
+     	
      	}
 #modified July 12,2007 to allow for NA in the overall matrix
 #modified July 9, 2008 to give statistical tests
 #modified yet again August 15 , 2008 to convert covariances to correlations
 #modified January 3, 2011 to work in the case of a single predictor 
 #modified April 25, 2011 to add the set correlation (from Cohen)
-#modified April 21, 2014 to allow for mixed names and locations in call
\ No newline at end of file
+#modified April 21, 2014 to allow for mixed names and locations in call
+
+
+
+setCor.diagram <- function(sc,main="Regression model",digits=2,show=TRUE,...) { 
+
+beta <- round(sc$beta,digits)
+x.matrix <- round(sc$x.matrix,digits)
+y.matrix <- round(sc$y.matrix,digits)
+x.names <- rownames(sc$beta)
+y.names <- colnames(sc$beta)
+nx <- length(x.names)
+ny <- length(y.names)
+top <- max(nx,ny)
+xlim=c(-nx/3,10)
+ylim=c(0,top)
+top <- max(nx,ny)
+x <- list()
+y <- list()
+x.scale <- top/(nx+1)
+y.scale <- top/(ny+1)
+plot(NA,xlim=xlim,ylim=ylim,main=main,axes=FALSE,xlab="",ylab="")
+for(i in 1:nx) {x[[i]] <- dia.rect(3,top-i*x.scale,x.names[i]) }
+ 
+for (j in 1:ny) {y[[j]] <- dia.rect(7,top-j*y.scale,y.names[j]) }
+for(i in 1:nx) {
+  for (j in 1:ny) {
+   dia.arrow(x[[i]]$right,y[[j]]$left,labels = beta[i,j],adj=4-j)
+   }
+} 
+if(nx >1) {
+  for (i in 2:nx) {
+  for (k in 1:(i-1)) {dia.curved.arrow(x[[i]]$left,x[[k]]$left,x.matrix[i,k],scale=-(abs(i-k)))} 
+  } }
+  
+  if(ny>1) {for (i in 2:ny) {
+  for (k in 1:(i-1)) {dia.curved.arrow(y[[i]]$right,y[[k]]$right,y.matrix[i,k],scale=(abs(i-k)))} 
+  }}
+  for(i in 1:ny) {dia.self(y[[i]],side=3,scale=.2) }
+ if(show) {text((10-nx/3)/2,0,paste("unweighted matrix correlation  = ",round(sc$Ruw,digits)))}
+}
+		 
+     		 
+     	
\ No newline at end of file
