@@ -1,9 +1,10 @@
 # A function to create a correlation matrix with a hierarchical structure
 # The default values match those of Jensen and Weng
+#dropped the call to mvrnorm Nov 28, 2014
 "sim.hierarchical" <-
 function (gload=NULL,fload=NULL,n=0,raw=FALSE,mu = NULL) {
 cl <- match.call()
- require(MASS)
+# require(MASS)
  if(is.null(gload)) gload=matrix(c(.9,.8,.7),nrow=3)
  if(is.null(fload)) {fload <-matrix(c(.8,.7,.6,rep(0,9),.7,.6,.5,rep(0,9),.6,.5,.4),   ncol=3)}
 
@@ -14,8 +15,13 @@ cl <- match.call()
   nvar <- dim(fload)[1]
   colnames(model) <- rownames(model) <- paste("V",1:nvar,sep="")
   if(n>0) {
-    if(is.null(mu)) mu <- rep(0,nvar)
-  	observed <- mvrnorm(n = n, mu, Sigma=model, tol = 1e-6, empirical = FALSE)
+   # if(is.null(mu)) mu <- rep(0,nvar)
+  	#observed <- mvrnorm(n = n, mu, Sigma=model, tol = 1e-6, empirical = FALSE)
+  	 #the next 3 lines replaces mvrnorm (adapted from mvrnorm, but without the checks)
+                                      eX <- eigen(model)
+                                      observed <- matrix(rnorm(nvar * n),n)
+                                      observed <- t( eX$vectors %*% diag(sqrt(pmax(eX$values, 0)), nvar) %*%  t(observed))
+                                      colnames(observed) <- paste("V",1:nvar,sep="")
   	 r <- cor(observed)
   	 if(!raw) { 
   	        result <- list(model=model, r= r, N=n,Call=cl) } else {
